package org.example.lc.service.mq;

import lombok.extern.slf4j.Slf4j;
import org.example.lc.pojo.domain.QuitResource;
import org.example.lc.pojo.domain.RecoveryResource;
import org.example.lc.service.MainService;
import org.example.lc.utlis.JsonUtil;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

@Slf4j
@Component
public class QuitReceiver {
    @Autowired
    private MainService mainService;

    @Value("${queue.name.quit}")
    private String queueName;

    @RabbitListener(queues = "#{@quitQueueName}")
    public void process(String msg) {
        log.info("{} receive msg:{}", queueName, msg);
        QuitResource resource = JsonUtil.deserialize(msg, QuitResource.class);
        if (resource == null || CollectionUtils.isEmpty(resource.getSystemCodes())) {
            log.error("报文有误");
            return;
        }
        resource.getSystemCodes().stream().forEach(item -> {
            mainService.quit(item, resource.getInfo());
        });
    }
}
